@@ -1,8 +1,8 @@
 from django.core.management import BaseCommand
 from django.db import connections
 
-from isapilib.Connection import create_conn
-from isapilib.models import SepaBranch
+from isapilib.api.models import SepaBranch
+from isapilib.external.connection import create_conn
 
 
 class Command(BaseCommand):
