@@ -2,8 +2,8 @@ from django.core.management.base import CommandError
 from django.core.management.commands.migrate import Command as MigrateCommand
 from django.db import connections
 
-from isapilib.Connection import create_conn
-from isapilib.models import SepaBranch
+from isapilib.api.models import SepaBranch
+from isapilib.external.connection import create_conn
 
 
 class Command(MigrateCommand):
